// $Id: CvsCheckOutDialog.cpp,v 1.10 2012/02/21 11:38:40 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "CvsCheckOutDialog.h"

#include <QtGui/QCheckBox>
#include <QtGui/QLabel>
#include <QtGui/QLayout>

//________________________________________________________________
CvsCheckOutDialog::CvsCheckOutDialog( QWidget* parent ):
CustomDialog( parent ),
state_( false )
{
    Debug::Throw( "CvsCheckOutDialog::CvsCheckOutDialog.\n" );
    QVBoxLayout* layout( new QVBoxLayout() );
    layout->setMargin(0);
    layout->setSpacing(5);
    mainLayout().addLayout( layout );

    layout->addWidget( new QLabel( "CVS Root directory: ", this ) );
    layout->addWidget( rootEditor_ = new AnimatedLineEditor( this ) );

    layout->addWidget( new QLabel( "Module names (use \",\" to separate modules): ", this ) );
    layout->addWidget( moduleEditor_ = new AnimatedLineEditor( this ) );

    localNameCheckBox_ = new QCheckBox( "Use a different name for the local directory", this );
    layout->addWidget( localNameCheckBox_ );
    layout->addWidget( localNameEditor_ = new AnimatedLineEditor( this ) );
    localNameEditor_->setEnabled( localNameCheckBox_->isChecked() );

    connect( localNameCheckBox_, SIGNAL( toggled( bool ) ), localNameEditor_, SLOT( setEnabled( bool ) ) );
    connect( moduleEditor_, SIGNAL( textChanged( const QString& ) ), SLOT( _checkModules( const QString& ) ) );

    adjustSize();

    return;
}

//______________________________________________________________
QList<QString> CvsCheckOutDialog::modules( void ) const
{

    Debug::Throw( "CvsCheckOutDialog::modules.\n" );
    QStringList modules_list( moduleEditor_->text().split( ",", QString::SkipEmptyParts ) );
    QList<QString> out;
    for( QStringList::iterator iter = modules_list.begin(); iter != modules_list.end(); ++iter )
    { out.push_back( iter->trimmed() ); }
    return out;

}


//________________________________________________________________
void CvsCheckOutDialog::_checkModules( const QString& value )
{

    if( value.indexOf( "," ) >= 0 )
    {
        state_ = localNameCheckBox_->isChecked();
        localNameCheckBox_->setChecked( false );
        localNameCheckBox_->setEnabled( false );
    } else if( !localNameCheckBox_->isEnabled() ) {
        localNameCheckBox_->setEnabled( true );
        localNameCheckBox_->setChecked( state_ );
    }

}
