#ifndef CvsCommandModel_h
#define CvsCommandModel_h

// $Id: CvsCommandModel.h,v 1.11 2012/09/06 16:09:52 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file    CvsCommandModel.h
\brief   Stores ftp commands for display in lists
\author  Hugo Pereira
\version $Revision: 1.11 $
\date    $Date: 2012/09/06 16:09:52 $
*/

#include "Counter.h"
#include "ListModel.h"
#include "CvsCommand.h"

#include <QtCore/QHash>

//! Job model. Stores job information for display in lists
class CvsCommandModel : public ListModel<CvsCommand>, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    CvsCommandModel(QObject *parent = 0);

    //! destructor
    virtual ~CvsCommandModel()
    {}

    //! number of columns
    enum { nColumns = 3 };

    //! column type enumeration
    enum ColumnType {
        ID,
        NAME,
        PATH
    };

    //!@name methods reimplemented from base class
    //@{

    //! data
    virtual QVariant data(const QModelIndex &index, int role) const;

    //! header data
    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;

    //! number of columns for a given index
    // virtual int columnCount(const QModelIndex &parent = QModelIndex()) const
    virtual int columnCount(const QModelIndex & = QModelIndex()) const
    { return nColumns; }

    //@}

    public slots:

    //! add file
    virtual void add( CvsCommand command );

    //! remove
    virtual void remove( CvsCommand command );

    private slots:

    //! update configuration
    void _updateConfiguration( void );

    protected:

    //! sort
    virtual void _sort( int column, Qt::SortOrder order = Qt::AscendingOrder )
    {}

    private:

    //! icon cache
    typedef QHash<CvsCommand::Type, QIcon> IconCache;

    //! install pixmaps
    void _installIcons( void ) const;

    //! type icon cache for local modifications
    static IconCache& _icons( void );

    //! list column names
    static const QString columnTitles_[nColumns];

};

#endif
