
// $Id: CvsLockDialog.cpp,v 1.8 2011/11/15 15:33:09 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
  \file CvsLockDialog.cpp
  \brief cvs lock action dialog
  \author Hugo Pereira
  \version $Revision: 1.8 $
  \date $Date: 2011/11/15 15:33:09 $
*/

#include <QLabel>

#include "BaseIcons.h"
#include "CvsLockDialog.h"
#include "Debug.h"
#include "PixmapEngine.h"
#include "XmlOptions.h"



//______________________________________________________________________________________________
CvsLockDialog::CvsLockDialog( QWidget* parent, const QString& user, const QString& path ):
  CustomDialog( parent )
{

  Debug::Throw( "CvsLockDialog::CvsLockDialog.\n" );

  // create label
  QString buffer;
  QTextStream( &buffer )
    << "Found CVS lock in " << path << " held by user " << user << endl
    << "Abort pending actions ?";
  QLabel* label = new QLabel( buffer, this );

  // create warning pixmap
  QPixmap question_pixmap( PixmapEngine::get( ICONS::WARNING ) );

  // insert main vertical box
  if( question_pixmap.isNull() )
  { mainLayout().addWidget( label, 1, Qt::AlignHCenter ); }
  else
  {
    QHBoxLayout *h_layout( new QHBoxLayout() );
    mainLayout().addLayout( h_layout, 1 );
    QLabel* pixmap_label = new QLabel( this );
    pixmap_label->setPixmap( question_pixmap );
    h_layout->addWidget( pixmap_label, 0, Qt::AlignHCenter );
    h_layout->addWidget( label, 1, Qt::AlignHCenter );
  }

  // rename buttons
  okButton().setToolTip(
    "All pending actions will be aborted.\n"
    "User must take actions to remove the existing lock, \n"
    "or wait for the lock to be removed externally." );

  cancelButton().setToolTip( "The current action is kept pending untill the lock is removed." );

}
